<?php

namespace InSegment\ApiCore\Models;

use Illuminate\Database\Eloquent\Model;

abstract class BaseOperation extends Model
{
    const STATUS_ACTIVE = 'active';
    const STATUS_ABORT = 'abort';
    const STATUS_DONE = 'done';
    const STATUS_CLEAN = 'clean';
    
    const STATUSES = [self::STATUS_ACTIVE, self::STATUS_ABORT, self::STATUS_DONE, self::STATUS_CLEAN];
    
    /**
     * Fillable attributes
     * 
     * @var array
     */
    protected $fillable = [
        'uid',
        'status'
    ];
    
    /**
     * The primary key for the model.
     *
     * @var string
     */
    protected $primaryKey = 'uid';
    
    /**
     * Indicate the uid is not incrementing
     * 
     * @var bool 
     */
    public $incrementing = false;

    /**
     * The model has timestamps
     * 
     * @var bool
     */
    public $timestamps = true;
    
    /**
     * Select outdated BaseOperations
     * 
     * @param \Illuminate\Database\Eloquent\Builder $query
     * @return \Illuminate\Database\Eloquent\Builder
     */
    public function scopeOutdated($query)
    {
        $lifetimeMinutes = (int) config('api_core.session_lifetime', config('session.lifetime'));
        
        return $query->whereRaw("`updated_at` < UTC_TIMESTAMP() - INTERVAL {$lifetimeMinutes} MINUTE");
    }
}
